@@ -10,18 +10,18 @@ use warnings;
 use warnings::register;
 
 use vars qw($VERSION $DATE $FILE );
-$VERSION = '0.01';
-$DATE = '2003/06/24';
+$VERSION = '0.02';
+$DATE = '2003/07/03';
 $FILE = __FILE__;
 
 use vars qw(%INVENTORY);
 %INVENTORY = (
-    'lib/Docs/Site_SVD/File_Package.pm' => [qw(0.01 2003/06/24), 'revised 0.03'],
-    'MANIFEST' => [qw(0.01 2003/06/24), 'generated, replaces 0.03'],
-    'Makefile.PL' => [qw(0.01 2003/06/24), 'generated, replaces 0.03'],
-    'README' => [qw(0.01 2003/06/24), 'generated, replaces 0.03'],
-    'lib/File/Package.pm' => [qw(1.1 2003/06/24), 'revised 1.09'],
-    't/File/package.t' => [qw(0.07 2003/06/24), 'revised 0.06'],
+    'lib/Docs/Site_SVD/File_Package.pm' => [qw(0.02 2003/07/03), 'revised 0.01'],
+    'MANIFEST' => [qw(0.02 2003/07/03), 'generated, replaces 0.01'],
+    'Makefile.PL' => [qw(0.02 2003/07/03), 'generated, replaces 0.01'],
+    'README' => [qw(0.02 2003/07/03), 'generated, replaces 0.01'],
+    'lib/File/Package.pm' => [qw(1.11 2003/07/03), 'revised 1.1'],
+    't/File/package.t' => [qw(0.08 2003/07/03), 'revised 0.07'],
 
 );
 
@@ -48,11 +48,11 @@ use vars qw(%INVENTORY);
 
   File::FileUtil - Generic file utilites developed originally for Test::STDmaker and ExtUtils::SVDmaker
 
- Revision: -
+ Revision: A
 
- Version: 0.01
+ Version: 0.02
 
- Date: 2003/06/24
+ Date: 2003/07/03
 
  Prepared for: General Public 
 
@@ -95,7 +95,7 @@ in failure report back to the author of the package.
 
 =head2 1.3 Document overview.
 
-This document releases File::Package version 0.01
+This document releases File::Package version 0.02
 providing a description of the inventory, installation
 instructions and other information necessary to
 utilize and track this release.
@@ -111,8 +111,8 @@ system file specification.
 This document releases the file found
 at the following repository(s):
 
-   http://www.softwarediamonds/packages/File-Package-0.01
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-Package-0.01
+   http://www.softwarediamonds/packages/File-Package-0.02
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-Package-0.02
 
 
 Restrictions regarding duplication and license provisions
@@ -180,17 +180,17 @@ consists of the following files:
 
  file                                                         version date       comment
  ------------------------------------------------------------ ------- ---------- ------------------------
- lib/Docs/Site_SVD/File_Package.pm                            0.01    2003/06/24 revised 0.03
- MANIFEST                                                     0.01    2003/06/24 generated, replaces 0.03
- Makefile.PL                                                  0.01    2003/06/24 generated, replaces 0.03
- README                                                       0.01    2003/06/24 generated, replaces 0.03
- lib/File/Package.pm                                          1.1     2003/06/24 revised 1.09
- t/File/package.t                                             0.07    2003/06/24 revised 0.06
+ lib/Docs/Site_SVD/File_Package.pm                            0.02    2003/07/03 revised 0.01
+ MANIFEST                                                     0.02    2003/07/03 generated, replaces 0.01
+ Makefile.PL                                                  0.02    2003/07/03 generated, replaces 0.01
+ README                                                       0.02    2003/07/03 generated, replaces 0.01
+ lib/File/Package.pm                                          1.11    2003/07/03 revised 1.1
+ t/File/package.t                                             0.08    2003/07/03 revised 0.07
 
 
 =head2 3.3 Changes
 
-The file names from 0.03 were changed as follows:
+The file names from 0.01 were changed as follows:
 
  return if $file =~ s=lib/File/FileUtil.pm=lib/File/Package.pm=;
  return if $file =~ s=t/File/FileUtil/FileUtil.t=t/File/package.t=;
@@ -295,7 +295,7 @@ t/Test/TestUtil/TestUtil....NOK 18# Test 18 got: '$VAR1 = '\\=head1 Title Page
   File::FileUtil - Generic file utilites developed originally for Test::STDmaker and ExtUtils::SVDmaker
 
 
- Revision: -
+ Revision: A
 
 [snip]
 
@@ -450,13 +450,14 @@ Follow the instructions for the the chosen installation software.
 
 The distribution file is at the following respositories:
 
-   http://www.softwarediamonds/packages/File-Package-0.01
-   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-Package-0.01
+   http://www.softwarediamonds/packages/File-Package-0.02
+   http://www.perl.com/CPAN-local/authors/id/S/SO/SOFTDIA/File-Package-0.02
 
 
 =item Prerequistes.
 
-None.
+ None.
+
 
 =item Security, privacy, or safety precautions.
 
@@ -554,13 +555,13 @@ Plain Old Documentation
 __DATA__
 
 DISTNAME: File-Package^
-VERSION : 0.01^
+VERSION : 0.02^
 REPOSITORY_DIR: packages^
 FREEZE: 1^
 
-PREVIOUS_DISTNAME: File-FileUtil^
-PREVIOUS_RELEASE: 0.03^
-REVISION: -^
+PREVIOUS_DISTNAME:  ^
+PREVIOUS_RELEASE: 0.01^
+REVISION: A^
 AUTHOR  : SoftwareDiamonds.com E<lt>support@SoftwareDiamonds.comE<gt>^
 ABSTRACT: Generic file utilities originally developed to support Test::STDmaker^
 TITLE   :  File::FileUtil - Generic file utilites developed originally for Test::STDmaker and ExtUtils::SVDmaker^
@@ -593,6 +594,7 @@ t/File/package.t
 PREREQ_PM:  ^
 TESTS: t/File/package.t^
 EXE_FILES:  ^
+
 CHANGES:
 Removed the methods for loading a
 program module with the same name 
